# Caer: A Computer Vision library in Python, built for Humans
A Computer Vision library in Python with powerful image processing operations, including support for Deep Learning models built using the Keras framework

[![Downloads](https://pepy.tech/badge/caer)](https://pepy.tech/project/caer)
[![license](https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000)](https://github.com/jasmcaus/caer/blob/master/LICENSE)

## Installation
The `caer` package can be installed via a simple pip install command 

<pre>$ pip install caer</pre>

## Resources

- **Homepage:** <https://github.com/jasmcaus/caer/>
- **PyPi:** <https://pypi.org/project/caer/>
- **Docs:** <https://github.com/jasmcaus/caer/blob/master/DOCS.md>
- **Issue tracking:** <https://github.com/jasmcaus/caer/issues>

## Call for Contributors

This repository is actively being maintained. `caer` appreciates help from a wide range of different backgrounds. Work such as high-level documentation or website improvements are valuable and we would like to grow our team with people filling these roles. Small improvements or fixes are always appreciated and issues labeled as easy may be a good starting point.
Please read the [contribution guidelines](https://github.com/jasmcaus/caer/wiki/How-to-Contribute) before starting work on a pull request.